@@ -7,6 +7,13 @@ int main(int argc, char *argv[])
     QCoreApplication::setOrganizationName("TedvdB");
     QCoreApplication::setOrganizationDomain("peejseej.nl");
     QCoreApplication::setApplicationName("FourCircle");
+    /*a.setStyleSheet(
+        "QWidget { background-color: rgb(255,255,255); color: rgb(0,0,0); }"
+        "QPushButton{ background-color: rgb(12, 185, 223); color: rgb(255, 255, 255); border-radius: 8px; padding:8px; }"
+        "QTreeWidgetItem { background-color: rgb(12, 185, 223); color: rgb(255, 255, 255); border-radius: 8px; padding:8px; }"
+
+    );*/
+
 
     MainWindow w;
     #if defined(Q_WS_MAEMO_5)
