@@ -8,7 +8,7 @@
 #include "addtipdialog.h"
 #include <QtConcurrentRun>
 #include <QFutureWatcher>
-//#include <QThread>
+#include <QMenu>
 
 namespace Ui {
     class VenueDetails;
@@ -36,10 +36,17 @@ private:
 
     QFuture<f_venue> *future;
     QFutureWatcher<f_venue> *watcher;
+    QMenu * m;
+    void doMark(QString markAs);
+
 
 private slots:
+    void on_pbMark_clicked();
     void on_pbAddTip_clicked();
     void on_pbCheckin_clicked();
+    void mislocated_clicked();
+    void closed_clicked();
+    void duplicate_clicked();
 };
 
 #endif // VENUEDETAILS_H
